@@ -1,6 +1,6 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 from __future__ import annotations
 
@@ -15,16 +15,15 @@ import astroid
 from astroid import MANAGER, builder, nodes, objects, test_utils, util
 from astroid.bases import Instance
 from astroid.brain.brain_namedtuple_enum import _get_namedtuple_fields
+from astroid.const import PY312_PLUS, PY313_PLUS
 from astroid.exceptions import (
     AttributeInferenceError,
     InferenceError,
     UseInferenceDefault,
 )
-from astroid.nodes.node_classes import Const
-from astroid.nodes.scoped_nodes import ClassDef
 
 
-def assertEqualMro(klass: ClassDef, expected_mro: list[str]) -> None:
+def assertEqualMro(klass: nodes.ClassDef, expected_mro: list[str]) -> None:
     """Check mro names."""
     assert [member.qname() for member in klass.mro()] == expected_mro
 
@@ -50,13 +49,6 @@ class CollectionsDequeTests(unittest.TestCase):
         self.assertIn("insert", inferred.locals)
         self.assertIn("index", inferred.locals)
 
-    @test_utils.require_version(maxver="3.8")
-    def test_deque_not_py39methods(self):
-        inferred = self._inferred_queue_instance()
-        with self.assertRaises(AttributeInferenceError):
-            inferred.getattr("__class_getitem__")
-
-    @test_utils.require_version(minver="3.9")
     def test_deque_py39methods(self):
         inferred = self._inferred_queue_instance()
         self.assertTrue(inferred.getattr("__class_getitem__"))
@@ -134,7 +126,6 @@ class IOBrainTest(unittest.TestCase):
             self.assertEqual(raw.name, "FileIO")
 
 
-@test_utils.require_version("3.9")
 class TypeBrain(unittest.TestCase):
     def test_type_subscript(self):
         """
@@ -147,10 +138,10 @@ class TypeBrain(unittest.TestCase):
             """
         )
         val_inf = src.annotation.value.inferred()[0]
-        self.assertIsInstance(val_inf, astroid.ClassDef)
+        self.assertIsInstance(val_inf, nodes.ClassDef)
         self.assertEqual(val_inf.name, "type")
         meth_inf = val_inf.getattr("__class_getitem__")[0]
-        self.assertIsInstance(meth_inf, astroid.FunctionDef)
+        self.assertIsInstance(meth_inf, nodes.FunctionDef)
 
     def test_invalid_type_subscript(self):
         """
@@ -164,14 +155,13 @@ class TypeBrain(unittest.TestCase):
             """
         )
         val_inf = src.annotation.value.inferred()[0]
-        self.assertIsInstance(val_inf, astroid.ClassDef)
+        self.assertIsInstance(val_inf, nodes.ClassDef)
         self.assertEqual(val_inf.name, "str")
         with self.assertRaises(AttributeInferenceError):
             # pylint: disable=expression-not-assigned
             # noinspection PyStatementEffect
             val_inf.getattr("__class_getitem__")[0]
 
-    @test_utils.require_version(minver="3.9")
     def test_builtin_subscriptable(self):
         """Starting with python3.9 builtin types such as list are subscriptable.
         Any builtin class such as "enumerate" or "staticmethod" also works."""
@@ -186,12 +176,35 @@ class TypeBrain(unittest.TestCase):
 
 
 def check_metaclass_is_abc(node: nodes.ClassDef):
-    meta = node.metaclass()
-    assert isinstance(meta, nodes.ClassDef)
-    assert meta.name == "ABCMeta"
+    if PY312_PLUS and node.name == "ByteString":
+        # .metaclass() finds the first metaclass in the mro(),
+        # which, from 3.12, is _DeprecateByteStringMeta (unhelpful)
+        # until ByteString is removed in 3.17.
+        # Jump over the first two ByteString classes in the mro().
+        check_metaclass_is_abc(node.mro()[2])
+    else:
+        meta = node.metaclass()
+        assert isinstance(meta, nodes.ClassDef)
+        assert meta.name == "ABCMeta"
 
 
 class CollectionsBrain(unittest.TestCase):
+    def test_collections_abc_is_importable(self) -> None:
+        """
+        Test that we can import `collections.abc`.
+
+        The collections.abc has gone through various formats of being frozen. Therefore, we ensure
+        that we can still import it (correctly).
+        """
+        import_node = builder.extract_node("import collections.abc")
+        assert isinstance(import_node, nodes.Import)
+        imported_module = import_node.do_import_module(import_node.names[0][0])
+        # Make sure that the file we have imported is actually the submodule of collections and
+        # not the `abc` module. (Which would happen if you call `importlib.util.find_spec("abc")`
+        # instead of `importlib.util.find_spec("collections.abc")`)
+        assert isinstance(imported_module.file, str)
+        assert "collections" in imported_module.file
+
     def test_collections_object_not_subscriptable(self) -> None:
         """
         Test that unsubscriptable types are detected
@@ -223,7 +236,6 @@ class CollectionsBrain(unittest.TestCase):
         with self.assertRaises(AttributeInferenceError):
             inferred.getattr("__class_getitem__")
 
-    @test_utils.require_version(minver="3.9")
     def test_collections_object_subscriptable(self):
         """Starting with python39 some object of collections module are subscriptable. Test one of them"""
         right_node = builder.extract_node(
@@ -250,44 +262,6 @@ class CollectionsBrain(unittest.TestCase):
             inferred.getattr("__class_getitem__")[0], nodes.FunctionDef
         )
 
-    @test_utils.require_version(maxver="3.9")
-    def test_collections_object_not_yet_subscriptable(self):
-        """
-        Test that unsubscriptable types are detected as such.
-        Until python39 MutableSet of the collections module is not subscriptable.
-        """
-        wrong_node = builder.extract_node(
-            """
-        import collections.abc
-        collections.abc.MutableSet[int]
-        """
-        )
-        with self.assertRaises(InferenceError):
-            next(wrong_node.infer())
-        right_node = builder.extract_node(
-            """
-        import collections.abc
-        collections.abc.MutableSet
-        """
-        )
-        inferred = next(right_node.infer())
-        check_metaclass_is_abc(inferred)
-        assertEqualMro(
-            inferred,
-            [
-                "_collections_abc.MutableSet",
-                "_collections_abc.Set",
-                "_collections_abc.Collection",
-                "_collections_abc.Sized",
-                "_collections_abc.Iterable",
-                "_collections_abc.Container",
-                "builtins.object",
-            ],
-        )
-        with self.assertRaises(AttributeInferenceError):
-            inferred.getattr("__class_getitem__")
-
-    @test_utils.require_version(minver="3.9")
     def test_collections_object_subscriptable_2(self):
         """Starting with python39 Iterator in the collection.abc module is subscriptable"""
         node = builder.extract_node(
@@ -309,21 +283,8 @@ class CollectionsBrain(unittest.TestCase):
             ],
         )
 
-    @test_utils.require_version(maxver="3.9")
-    def test_collections_object_not_yet_subscriptable_2(self):
-        """Before python39 Iterator in the collection.abc module is not subscriptable"""
-        node = builder.extract_node(
-            """
-        import collections.abc
-        collections.abc.Iterator[int]
-        """
-        )
-        with self.assertRaises(InferenceError):
-            next(node.infer())
-
-    @test_utils.require_version(minver="3.9")
     def test_collections_object_subscriptable_3(self):
-        """With Python 3.9 the ByteString class of the collections module is subscritable
+        """With Python 3.9 the ByteString class of the collections module is subscriptable
         (but not the same class from typing module)"""
         right_node = builder.extract_node(
             """
@@ -337,7 +298,6 @@ class CollectionsBrain(unittest.TestCase):
             inferred.getattr("__class_getitem__")[0], nodes.FunctionDef
         )
 
-    @test_utils.require_version(minver="3.9")
     def test_collections_object_subscriptable_4(self):
         """Multiple inheritance with subscriptable collection class"""
         node = builder.extract_node(
@@ -359,6 +319,16 @@ class CollectionsBrain(unittest.TestCase):
             ],
         )
 
+    def test_statistics_quantiles_from_import(self):
+        node = builder.extract_node(
+            """
+        from statistics import quantiles
+        quantiles([1, 2, 3, 4, 5, 6, 7, 8, 9], n=4)
+        """
+        )
+        inferred = next(node.infer())
+        self.assertIs(inferred, util.Uninferable)
+
 
 class TypingBrain(unittest.TestCase):
     def test_namedtuple_base(self) -> None:
@@ -393,7 +363,7 @@ class TypingBrain(unittest.TestCase):
         )
         self.assertEqual(len(klass.getattr("as_string")), 1)
         inferred = next(called.infer())
-        self.assertIsInstance(inferred, astroid.Const)
+        self.assertIsInstance(inferred, nodes.Const)
         self.assertEqual(inferred.value, 5)
 
     def test_namedtuple_inference(self) -> None:
@@ -483,7 +453,7 @@ class TypingBrain(unittest.TestCase):
         self.assertIsInstance(inferred, astroid.Instance)
 
         class_attr = inferred.getattr("CLASS_ATTR")[0]
-        self.assertIsInstance(class_attr, astroid.AssignName)
+        self.assertIsInstance(class_attr, nodes.AssignName)
         const = next(class_attr.infer())
         self.assertEqual(const.value, "class_attr")
 
@@ -501,7 +471,7 @@ class TypingBrain(unittest.TestCase):
     def test_namedtuple_bug_pylint_4383(self) -> None:
         """Inference of 'NamedTuple' function shouldn't cause InferenceError.
 
-        https://github.com/PyCQA/pylint/issues/4383
+        https://github.com/pylint-dev/pylint/issues/4383
         """
         node = builder.extract_node(
             """
@@ -549,7 +519,7 @@ class TypingBrain(unittest.TestCase):
             self.assertIsInstance(inferred, nodes.ClassDef, node.as_string())
 
     def test_typing_type_without_tip(self):
-        """Regression test for https://github.com/PyCQA/pylint/issues/5770"""
+        """Regression test for https://github.com/pylint-dev/pylint/issues/5770"""
         node = builder.extract_node(
             """
         from typing import NewType
@@ -574,10 +544,10 @@ class TypingBrain(unittest.TestCase):
         """
         )
         inferred = next(result.infer())
-        self.assertIsInstance(inferred, astroid.ClassDef)
+        self.assertIsInstance(inferred, nodes.ClassDef)
 
         class_def_attr = inferred.getattr("Foo")[0]
-        self.assertIsInstance(class_def_attr, astroid.ClassDef)
+        self.assertIsInstance(class_def_attr, nodes.ClassDef)
         attr_def = class_def_attr.getattr("bar")[0]
         attr = next(attr_def.infer())
         self.assertEqual(attr.value, "bar")
@@ -619,9 +589,26 @@ class TypingBrain(unittest.TestCase):
         assert isinstance(inferred, nodes.ClassDef)
         assert isinstance(inferred.getattr("__class_getitem__")[0], nodes.FunctionDef)
 
-    @test_utils.require_version(minver="3.9")
+    @test_utils.require_version(minver="3.12")
+    def test_typing_generic_subscriptable_pep695(self):
+        """Test class using type parameters is subscriptable with __class_getitem__ (added in PY312)"""
+        node = builder.extract_node(
+            """
+        class Foo[T]: ...
+        class Bar[T](Foo[T]): ...
+        """
+        )
+        inferred = next(node.infer())
+        assert isinstance(inferred, nodes.ClassDef)
+        assert inferred.name == "Bar"
+        assert isinstance(inferred.getattr("__class_getitem__")[0], nodes.FunctionDef)
+        ancestors = list(inferred.ancestors())
+        assert len(ancestors) == 2
+        assert ancestors[0].name == "Foo"
+        assert ancestors[1].name == "object"
+
     def test_typing_annotated_subscriptable(self):
-        """Test typing.Annotated is subscriptable with __class_getitem__"""
+        """typing.Annotated is subscriptable with __class_getitem__ below 3.13."""
         node = builder.extract_node(
             """
         import typing
@@ -629,8 +616,13 @@ class TypingBrain(unittest.TestCase):
         """
         )
         inferred = next(node.infer())
-        assert isinstance(inferred, nodes.ClassDef)
-        assert isinstance(inferred.getattr("__class_getitem__")[0], nodes.FunctionDef)
+        if PY313_PLUS:
+            assert isinstance(inferred, nodes.FunctionDef)
+        else:
+            assert isinstance(inferred, nodes.ClassDef)
+            assert isinstance(
+                inferred.getattr("__class_getitem__")[0], nodes.FunctionDef
+            )
 
     def test_typing_generic_slots(self):
         """Test slots for Generic subclass."""
@@ -650,6 +642,36 @@ class TypingBrain(unittest.TestCase):
         assert isinstance(slots[0], nodes.Const)
         assert slots[0].value == "value"
 
+    def test_typing_no_duplicates(self):
+        node = builder.extract_node(
+            """
+        from typing import List
+        List[int]
+        """
+        )
+        assert len(node.inferred()) == 1
+
+    def test_typing_no_duplicates_2(self):
+        node = builder.extract_node(
+            """
+        from typing import Optional, Tuple
+        Tuple[Optional[int], ...]
+        """
+        )
+        assert len(node.inferred()) == 1
+
+    def test_typing_param_spec(self):
+        node = builder.extract_node(
+            """
+        from typing import ParamSpec
+
+        P = ParamSpec("P")
+        """
+        )
+        inferred = next(node.targets[0].infer())
+        assert next(inferred.igetattr("args")) is not None
+        assert next(inferred.igetattr("kwargs")) is not None
+
     def test_collections_generic_alias_slots(self):
         """Test slots for a class which is a subclass of a generic alias type."""
         node = builder.extract_node(
@@ -694,7 +716,6 @@ class TypingBrain(unittest.TestCase):
         inferred = next(node.infer())
         self.assertIsInstance(inferred, astroid.Instance)
 
-    @test_utils.require_version("3.8")
     def test_typed_dict(self):
         code = builder.extract_node(
             """
@@ -855,7 +876,7 @@ class TypingBrain(unittest.TestCase):
         )
 
     def test_typing_object_notsubscriptable_3(self):
-        """Until python39 ByteString class of the typing module is not
+        """The ByteString class of the typing module is not
         subscriptable (whereas it is in the collections' module)"""
         right_node = builder.extract_node(
             """
@@ -870,7 +891,6 @@ class TypingBrain(unittest.TestCase):
                 inferred.getattr("__class_getitem__")[0], nodes.FunctionDef
             )
 
-    @test_utils.require_version(minver="3.9")
     def test_typing_object_builtin_subscriptable(self):
         """
         Test that builtins alias, such as typing.List, are subscriptable
@@ -886,7 +906,6 @@ class TypingBrain(unittest.TestCase):
             self.assertIsInstance(inferred.getattr("__iter__")[0], nodes.FunctionDef)
 
     @staticmethod
-    @test_utils.require_version(minver="3.9")
     def test_typing_type_subscriptable():
         node = builder.extract_node(
             """
@@ -930,13 +949,7 @@ class TypingBrain(unittest.TestCase):
         assert inferred.value == 42
 
     def test_typing_cast_multiple_inference_calls(self) -> None:
-        """Inference of an outer function should not store the result for cast.
-
-        https://github.com/PyCQA/pylint/issues/8074
-
-        Possible solution caused RecursionErrors with Python 3.8 and CPython + PyPy.
-        https://github.com/PyCQA/astroid/pull/1982
-        """
+        """Inference of an outer function should not store the result for cast."""
         ast_nodes = builder.extract_node(
             """
         from typing import TypeVar, cast
@@ -954,7 +967,7 @@ class TypingBrain(unittest.TestCase):
 
         i1 = next(ast_nodes[1].infer())
         assert isinstance(i1, nodes.Const)
-        assert i1.value == 2  # should be "Hello"!
+        assert i1.value == "Hello"
 
 
 class ReBrainTest(unittest.TestCase):
@@ -965,56 +978,6 @@ class ReBrainTest(unittest.TestCase):
             self.assertIn(name, re_ast)
             self.assertEqual(next(re_ast[name].infer()).value, getattr(re, name))
 
-    @test_utils.require_version(maxver="3.9")
-    def test_re_pattern_unsubscriptable(self):
-        """
-        re.Pattern and re.Match are unsubscriptable until PY39.
-        """
-        right_node1 = builder.extract_node(
-            """
-        import re
-        re.Pattern
-        """
-        )
-        inferred1 = next(right_node1.infer())
-        assert isinstance(inferred1, nodes.ClassDef)
-        with self.assertRaises(AttributeInferenceError):
-            assert isinstance(
-                inferred1.getattr("__class_getitem__")[0], nodes.FunctionDef
-            )
-
-        right_node2 = builder.extract_node(
-            """
-        import re
-        re.Pattern
-        """
-        )
-        inferred2 = next(right_node2.infer())
-        assert isinstance(inferred2, nodes.ClassDef)
-        with self.assertRaises(AttributeInferenceError):
-            assert isinstance(
-                inferred2.getattr("__class_getitem__")[0], nodes.FunctionDef
-            )
-
-        wrong_node1 = builder.extract_node(
-            """
-        import re
-        re.Pattern[int]
-        """
-        )
-        with self.assertRaises(InferenceError):
-            next(wrong_node1.infer())
-
-        wrong_node2 = builder.extract_node(
-            """
-        import re
-        re.Match[int]
-        """
-        )
-        with self.assertRaises(InferenceError):
-            next(wrong_node2.infer())
-
-    @test_utils.require_version(minver="3.9")
     def test_re_pattern_subscriptable(self):
         """Test re.Pattern and re.Match are subscriptable in PY39+"""
         node1 = builder.extract_node(
@@ -1038,23 +1001,6 @@ class ReBrainTest(unittest.TestCase):
         assert isinstance(inferred2.getattr("__class_getitem__")[0], nodes.FunctionDef)
 
 
-class BrainFStrings(unittest.TestCase):
-    def test_no_crash_on_const_reconstruction(self) -> None:
-        node = builder.extract_node(
-            """
-        max_width = 10
-
-        test1 = f'{" ":{max_width+4}}'
-        print(f'"{test1}"')
-
-        test2 = f'[{"7":>{max_width}}:0]'
-        test2
-        """
-        )
-        inferred = next(node.infer())
-        self.assertIs(inferred, util.Uninferable)
-
-
 class BrainNamedtupleAnnAssignTest(unittest.TestCase):
     def test_no_crash_on_ann_assign_in_namedtuple(self) -> None:
         node = builder.extract_node(
@@ -1092,7 +1038,7 @@ class RandomSampleTest(unittest.TestCase):
         """
         )
         inferred = next(node.infer())
-        self.assertIsInstance(inferred, astroid.List)
+        self.assertIsInstance(inferred, nodes.List)
         elems = sorted(elem.value for elem in inferred.elts)
         self.assertEqual(elems, [1, 2])
 
@@ -1110,12 +1056,12 @@ class RandomSampleTest(unittest.TestCase):
         )
         # Check that arguments are of type `nodes.Call`.
         sequence, length = node.args
-        self.assertIsInstance(sequence, astroid.Call)
-        self.assertIsInstance(length, astroid.Call)
+        self.assertIsInstance(sequence, nodes.Call)
+        self.assertIsInstance(length, nodes.Call)
 
         # Check the inference of `random.sample` call.
         inferred = next(node.infer())
-        self.assertIsInstance(inferred, astroid.List)
+        self.assertIsInstance(inferred, nodes.List)
         elems = sorted(elem.value for elem in inferred.elts)
         self.assertEqual(elems, [1, 2])
 
@@ -1127,7 +1073,7 @@ class RandomSampleTest(unittest.TestCase):
         sample(list({1: A()}.values()), 1)"""
         )
         inferred = next(node.infer())
-        assert isinstance(inferred, astroid.List)
+        assert isinstance(inferred, nodes.List)
         assert len(inferred.elts) == 1
         assert isinstance(inferred.elts[0], nodes.Call)
 
@@ -1138,7 +1084,7 @@ class SubprocessTest(unittest.TestCase):
     def test_subprocess_args(self) -> None:
         """Make sure the args attribute exists for Popen
 
-        Test for https://github.com/PyCQA/pylint/issues/1860"""
+        Test for https://github.com/pylint-dev/pylint/issues/1860"""
         name = astroid.extract_node(
             """
         import subprocess
@@ -1158,10 +1104,9 @@ class SubprocessTest(unittest.TestCase):
         node = astroid.extract_node(code)
         inferred = next(node.infer())
         # Can be either str or bytes
-        assert isinstance(inferred, astroid.Const)
+        assert isinstance(inferred, nodes.Const)
         assert isinstance(inferred.value, (str, bytes))
 
-    @test_utils.require_version("3.9")
     def test_popen_does_not_have_class_getitem(self):
         code = """import subprocess; subprocess.Popen"""
         node = astroid.extract_node(code)
@@ -1414,7 +1359,7 @@ class TestIssubclassBrain:
             _get_result_node("issubclass(int, int, str)")
 
 
-def _get_result_node(code: str) -> Const:
+def _get_result_node(code: str) -> nodes.Const:
     node = next(astroid.extract_node(code).infer())
     return node
 
@@ -1594,7 +1539,7 @@ class TestLenBuiltinInference:
         """Make sure len builtin doesn't raise an AttributeError
         on instances of str or bytes
 
-        See https://github.com/PyCQA/pylint/issues/1942
+        See https://github.com/pylint-dev/pylint/issues/1942
         """
         code = 'len(str("F"))'
         try:
@@ -1608,7 +1553,7 @@ class TestLenBuiltinInference:
         """Make sure len calls do not trigger
         recursion errors for self referential assignment
 
-        See https://github.com/PyCQA/pylint/issues/2734
+        See https://github.com/pylint-dev/pylint/issues/2734
         """
         code = """
         class Data:
@@ -1635,7 +1580,7 @@ def test_infer_str() -> None:
     )
     for node in ast_nodes:
         inferred = next(node.infer())
-        assert isinstance(inferred, astroid.Const)
+        assert isinstance(inferred, nodes.Const)
 
     node = astroid.extract_node(
         """
@@ -1656,7 +1601,7 @@ def test_infer_int() -> None:
     )
     for node in ast_nodes:
         inferred = next(node.infer())
-        assert isinstance(inferred, astroid.Const)
+        assert isinstance(inferred, nodes.Const)
 
     ast_nodes = astroid.extract_node(
         """
@@ -1683,7 +1628,8 @@ def test_infer_dict_from_keys() -> None:
     )
     for node in bad_nodes:
         with pytest.raises(InferenceError):
-            next(node.infer())
+            if isinstance(next(node.infer()), util.UninferableBase):
+                raise InferenceError
 
     # Test uninferable values
     good_nodes = astroid.extract_node(
@@ -1697,7 +1643,7 @@ def test_infer_dict_from_keys() -> None:
     )
     for node in good_nodes:
         inferred = next(node.infer())
-        assert isinstance(inferred, astroid.Dict)
+        assert isinstance(inferred, nodes.Dict)
         assert inferred.items == []
 
     # Test inferable values
@@ -1709,9 +1655,9 @@ def test_infer_dict_from_keys() -> None:
     """
     )
     inferred = next(from_dict.infer())
-    assert isinstance(inferred, astroid.Dict)
+    assert isinstance(inferred, nodes.Dict)
     itered = inferred.itered()
-    assert all(isinstance(elem, astroid.Const) for elem in itered)
+    assert all(isinstance(elem, nodes.Const) for elem in itered)
     actual_values = [elem.value for elem in itered]
     assert sorted(actual_values) == ["a", "b", "c"]
 
@@ -1722,9 +1668,9 @@ def test_infer_dict_from_keys() -> None:
     """
     )
     inferred = next(from_string.infer())
-    assert isinstance(inferred, astroid.Dict)
+    assert isinstance(inferred, nodes.Dict)
     itered = inferred.itered()
-    assert all(isinstance(elem, astroid.Const) for elem in itered)
+    assert all(isinstance(elem, nodes.Const) for elem in itered)
     actual_values = [elem.value for elem in itered]
     assert sorted(actual_values) == ["a", "b", "c"]
 
@@ -1735,9 +1681,9 @@ def test_infer_dict_from_keys() -> None:
     """
     )
     inferred = next(from_bytes.infer())
-    assert isinstance(inferred, astroid.Dict)
+    assert isinstance(inferred, nodes.Dict)
     itered = inferred.itered()
-    assert all(isinstance(elem, astroid.Const) for elem in itered)
+    assert all(isinstance(elem, nodes.Const) for elem in itered)
     actual_values = [elem.value for elem in itered]
     assert sorted(actual_values) == [97, 98, 99]
 
@@ -1751,9 +1697,9 @@ def test_infer_dict_from_keys() -> None:
     )
     for node in from_others:
         inferred = next(node.infer())
-        assert isinstance(inferred, astroid.Dict)
+        assert isinstance(inferred, nodes.Dict)
         itered = inferred.itered()
-        assert all(isinstance(elem, astroid.Const) for elem in itered)
+        assert all(isinstance(elem, nodes.Const) for elem in itered)
         actual_values = [elem.value for elem in itered]
         assert sorted(actual_values) == ["a", "b", "c"]
 
@@ -1775,11 +1721,9 @@ class TestFunctoolsPartial:
         assert len(inferred) == 1
         partial = inferred[0]
         assert isinstance(partial, objects.PartialFunction)
+        assert isinstance(partial.as_string(), str)
         assert isinstance(partial.doc_node, nodes.Const)
         assert partial.doc_node.value == "Docstring"
-        with pytest.warns(DeprecationWarning) as records:
-            assert partial.doc == "Docstring"
-            assert len(records) == 1
         assert partial.lineno == 3
         assert partial.col_offset == 0
 
@@ -1803,7 +1747,7 @@ class TestFunctoolsPartial:
         )
         for node in ast_nodes:
             inferred = next(node.infer())
-            assert isinstance(inferred, (astroid.FunctionDef, astroid.Instance))
+            assert isinstance(inferred, (nodes.FunctionDef, astroid.Instance))
             assert inferred.qname() in {
                 "functools.partial",
                 "functools.partial.newfunc",
@@ -1834,7 +1778,7 @@ class TestFunctoolsPartial:
         expected_values = [4, 7, 7, 3, 12, 16, 32, 36, 3, 9, 7]
         for node, expected_value in zip(ast_nodes, expected_values):
             inferred = next(node.infer())
-            assert isinstance(inferred, astroid.Const)
+            assert isinstance(inferred, nodes.Const)
             assert inferred.value == expected_value
 
     def test_partial_assignment(self) -> None:
@@ -1935,7 +1879,7 @@ def test_http_status_brain() -> None:
     """
     )
     inferred = next(node.infer())
-    assert isinstance(inferred, astroid.Const)
+    assert isinstance(inferred, nodes.Const)
 
 
 def test_http_status_brain_iterable() -> None:
@@ -1962,10 +1906,11 @@ def test_oserror_model() -> None:
     )
     inferred = next(node.infer())
     strerror = next(inferred.igetattr("strerror"))
-    assert isinstance(strerror, astroid.Const)
+    assert isinstance(strerror, nodes.Const)
     assert strerror.value == ""
 
 
+@pytest.mark.skipif(PY313_PLUS, reason="Python >= 3.13 no longer has a crypt module")
 def test_crypt_brain() -> None:
     module = MANAGER.ast_from_module_name("crypt")
     dynamic_attrs = [
@@ -1982,9 +1927,9 @@ def test_crypt_brain() -> None:
 @pytest.mark.parametrize(
     "code,expected_class,expected_value",
     [
-        ("'hey'.encode()", astroid.Const, b""),
-        ("b'hey'.decode()", astroid.Const, ""),
-        ("'hey'.encode().decode()", astroid.Const, ""),
+        ("'hey'.encode()", nodes.Const, b""),
+        ("b'hey'.decode()", nodes.Const, ""),
+        ("'hey'.encode().decode()", nodes.Const, ""),
     ],
 )
 def test_str_and_bytes(code, expected_class, expected_value):
@@ -1996,7 +1941,7 @@ def test_str_and_bytes(code, expected_class, expected_value):
 
 def test_no_recursionerror_on_self_referential_length_check() -> None:
     """
-    Regression test for https://github.com/PyCQA/astroid/issues/777
+    Regression test for https://github.com/pylint-dev/astroid/issues/777
 
     This test should only raise an InferenceError and no RecursionError.
     """
@@ -2015,8 +1960,8 @@ def test_no_recursionerror_on_self_referential_length_check() -> None:
 
 def test_inference_on_outer_referential_length_check() -> None:
     """
-    Regression test for https://github.com/PyCQA/pylint/issues/5244
-    See also https://github.com/PyCQA/astroid/pull/1234
+    Regression test for https://github.com/pylint-dev/pylint/issues/5244
+    See also https://github.com/pylint-dev/astroid/pull/1234
 
     This test should succeed without any error.
     """
@@ -2042,8 +1987,8 @@ def test_inference_on_outer_referential_length_check() -> None:
 
 def test_no_attributeerror_on_self_referential_length_check() -> None:
     """
-    Regression test for https://github.com/PyCQA/pylint/issues/5244
-    See also https://github.com/PyCQA/astroid/pull/1234
+    Regression test for https://github.com/pylint-dev/pylint/issues/5244
+    See also https://github.com/pylint-dev/astroid/pull/1234
 
     This test should only raise an InferenceError and no AttributeError.
     """
